@@ -2,6 +2,7 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from cms.models import CMSPlugin, Page
 
+
 class Link(CMSPlugin):
     """
     A link to an other page or to an external website
@@ -10,6 +11,8 @@ class Link(CMSPlugin):
     url = models.URLField(_("link"), blank=True, null=True)
     page_link = models.ForeignKey(Page, verbose_name=_("page"), blank=True, null=True, help_text=_("A link to a page has priority over a text link."))
     mailto = models.EmailField(_("mailto"), blank=True, null=True, help_text=_("An email adress has priority over a text link."))
+    phone = models.CharField(_('Phone'), blank=True, null=True, max_length=40,
+                             help_text=_('A phone number has priority over a mailto link.'))
     target = models.CharField(_("target"), blank=True, max_length=100, choices=((
         ("", _("same window")),
         ("_blank", _("new window")),
